@@ -15,7 +15,11 @@ def main():
     )
     parser.add_argument("language", help="Output language")
     parser.add_argument(
-        "src", help="Source file (will be fetched if not passed)", nargs="?", type=FileType("r"), default=None,
+        "src",
+        help="Source file (will be fetched if not passed)",
+        nargs="?",
+        type=FileType("r"),
+        default=None,
     )
     parser.add_argument(
         "--overwrite", "-o", help="Delete conflicting files before emitting (default: exit)", action="store_true"
