@@ -1,4 +1,5 @@
 from io import BufferedIOBase
+from hashlib import sha1
 from os.path import dirname, realpath
 
 from lxml import etree
@@ -6,6 +7,16 @@ from lxml import etree
 from urllib.request import urlopen
 
 
+class StableHashedString(str):
+    slots = []
+
+    def __hash__(self):
+        h = sha1()
+        h.update(self.encode())
+        h = h.hexdigest()
+        return int(h, 16)
+
+
 class Param:
     slots = ["name", "types", "is_required"]
 
@@ -170,13 +181,13 @@ class ApiParser:
 
         # begin with the types used in the endpoints (excluding primitives)
         used_type_names = set(
-            base_type
+            StableHashedString(base_type)
             for endpoint in endpoints
             # endpoint = (name, params)
             for param in endpoint[1]
             for _type in param.types
             # _type[0] always contains either the type itself or the wrapped type (Array<T>)
-            if (base_type := _type[0]) not in skipped_types
+            if not ((base_type := _type[0]) in skipped_types or skipped_types.add(base_type))
         )
 
         _used_type_names = set()
@@ -186,15 +197,18 @@ class ApiParser:
         # keep track of the types used by each type
         while True:
             for type_name in used_type_names:
-                if (type_aliases := aliases.get(type_name, None)) :
+                # we need to hash a normal string
+                _type_name = str(type_name)
+
+                if (type_aliases := aliases.get(_type_name, None)) :
                     # if the type has aliases we process it and add the aliases
                     _used_type_names.update(alias for alias in type_aliases)
 
-                elif (_type := types.get(type_name, None)) :
+                elif (_type := types.get(_type_name, None)) :
                     # if we have found a definition add the definition and process other custom types (if there's any)
                     used_types_reversed.append(_type)
                     _used_type_names.update(
-                        base_type
+                        StableHashedString(base_type)
                         for param in _type[1]
                         for param_type in param.types
                         if not ((base_type := param_type[0]) in skipped_types or skipped_types.add(base_type))
@@ -207,7 +221,6 @@ class ApiParser:
             used_type_names.clear()
             used_type_names, _used_type_names = _used_type_names, used_type_names
 
-        used_types_reversed.reverse()
-        used_types.extend(used_types_reversed)
+        used_types.extend(reversed(used_types_reversed))
 
         return api_version, endpoints, used_types, reversed_aliases
